pub trait View: ViewRaw {
// Required methods
fn try_set_min(self, min: i32, ctx: &mut Context<'_>) -> Option<i32>;
fn try_set_max(self, max: i32, ctx: &mut Context<'_>) -> Option<i32>;
// Provided methods
fn get_underlying_var(self) -> Option<VarId> { ... }
fn min(self, ctx: &Context<'_>) -> i32 { ... }
fn max(self, ctx: &Context<'_>) -> i32 { ... }
}Expand description
Apply simple domain transformations on the fly to make propagators more generic.
Required Methods
Provided Methods
Sourcefn get_underlying_var(self) -> Option<VarId>
fn get_underlying_var(self) -> Option<VarId>
Get the handle of the variable this view depends on.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".